#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for V4l2ucp
#---( Home Page: http://sourceforge.net/projects/v4l2ucp/
#---( Source URL: http://sourceforge.net/project/downloading.php?group_id=146218&filename=v4l2ucp-1.3.tar.gz&a=29088751
#---( Build script by R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Wednesday 14-April-2009.


#------------------( Set Package Name & Version )


soft='v4l2ucp'
softversion='1.3'
packageversion='62.1'


#------------------( Check for source files )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Copy it first."
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src
./configure --prefix=/usr
make
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a COPYING README $dest/usr/doc/$soft-$softversion


#------------------( Copy The Build Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
v4l2ucp: v4l2ucp (Control panel for Video for Linux devices)
v4l2ucp: 
v4l2ucp: Universal control panel for Video for Linux Two (V4L2) devices.
v4l2ucp: Using this program we can control the video quality.
v4l2ucp: 
v4l2ucp: 
v4l2ucp: 
v4l2ucp: 
v4l2ucp: 
v4l2ucp:
v4l2ucp:
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5
zen-pkgcheck.pl $package.tgz
requiredbuilder -z $package.tgz > $package.dep
